@@ -1,5 +1,5 @@
 compute.threshold.FPF.AROC.sp <-
-function(object, newdata, FPF = 0.5, parallel = c("no", "multicore", "snow"), ncpus = 1, cl = NULL) {
+function(object, newdata, FPF = 0.5, ci.level = 0.95, parallel = c("no", "multicore", "snow"), ncpus = 1, cl = NULL) {
 	if(class(object)[1] != "AROC.sp") {
 		stop(paste0("This function cannot be used for this object class: ", class(object)[1]))
 	}
@@ -14,6 +14,7 @@ function(object, newdata, FPF = 0.5, parallel = c("no", "multicore", "snow"), nc
 	if(missing(newdata)) {
 		newdata <- cROCData(object$data, names.cov, object$group)
 	} else {
+		newdata <- as.data.frame(newdata)
 		newdata <- na.omit(newdata[,names.cov,drop = FALSE])
 	}  
 
